# LAHG Automatic Differentiation [![Build Status](https://app.travis-ci.com/cs107-lahg/cs107-FinalProject.svg?token=EBNKXkiBqDrUCF2XhQZz&branch=main)](https://app.travis-ci.com/cs107-lahg/cs107-FinalProject) [![codecov](https://codecov.io/gh/cs107-lahg/cs107-FinalProject/branch/main/graph/badge.svg?token=8M04YJW24L)](https://codecov.io/gh/cs107-lahg/cs107-FinalProject)

A simple package for automatic differentiation for Harvard AC207/CS107.

## Group number: 34

## Members: Hazel, Geoffrey, Anjali, Ling

## Broader Impact and Inclusivity Statement

### The potential broader impacts and implications of your software

Automatic differentiation has large impact in many fields in including Statistics, Mathematics, Bioinformatics, Machine Learning and so on. Its application diverges in various context not only in scientific research, but also in business and governance. Nowadays these data-driven technologies that employs automatic differentiation as its basic algorithm has shaped the world to be a better one. It provides more accurate fiancial service using NLP, provide medical artificial intelligence to advice physicians, as well as making more accuracy predictions of Economic treand.

As developed in recent years, machine learning and deep learning technologies have been applied in many fields, expecially in IT industry for advertisement recommendation, user classification, and facial recognization. However, these applications rely on the collection and potential misuse of personal data, sometimes without their awareness and consent. In this aspect, these applications are at risk causing harms to the society and public.

After though consideration, we still would like to distribute our package on PyPI, as its benefits overweigh its potential harms. We also require all those would like to make use of this package be aware of the negative impact of these technologies.

### How is your software inclusive to the broader community?

The package is freely distributed through PyPI, it should be accessible to anyone who has Internet access. Those who are interested in applying automatic differentiation function can easily install our package through either Github or PyPI, but we have also recognized that lack of Internet access could be a potential problem of accessing this package.

Our code is also open-sourced under the protection of MIT license, which means everyone could contribute to our code base, which is welcomed and encouraged. Our teammates will review the pull request and carefully evaluate the quality of code contribution without discriminating against race, color, religion, gender, gender expression, age, national origin, disability, marital status, sexual orientation, or military status, in any of its activities or operations. If a pull request is rejected, detailed comments will be provided.
